@@ -199,7 +199,7 @@ void ZoneClockPanel::addClock(const QString &zone, const QString &name)
 
   realign();
 
-  connect(zc, SIGNAL(addClock(QString)), this, SLOT(addClock(QString)));
+  connect(zc, SIGNAL(addClock(const QString &)), this, SLOT(addClock(const QString &)));
   connect(zc, SIGNAL(changed()), this, SLOT(realign()));
   connect(zc, SIGNAL(removeMe(ZoneClock *)), this, SLOT(removeClock(ZoneClock *)));
 }
@@ -233,7 +233,7 @@ void ZoneClockPanel::updateTimer()
     it.current()->updateTime();
 }
 
-void ZoneClockPanel::addClock(QString zone)
+void ZoneClockPanel::addClock(const QString &zone)
 {
   createDialog();
 
